services

package
v0.0.57 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithAccessControlAbacWhatScopeListOrder

func WithAccessControlAbacWhatScopeListOrder(input ...types.AccessWhatOrderByInput) func(options *AccessControlAbacWhatScopeListOptions)

WithAccessControlAbacWhatScopeListOrder can be used to specify the order of the returned AccessControlAbacWhatScopeList.

func WithAccessControlAbacWhatScopeListSearch

func WithAccessControlAbacWhatScopeListSearch(search string) func(options *AccessControlAbacWhatScopeListOptions)

WithAccessControlAbacWhatScopeListSearch can be used to specify the search of the returned Access

func WithAccessControlListFilter

func WithAccessControlListFilter(input *types.AccessControlFilterInput) func(options *AccessControlListOptions)

WithAccessControlListFilter can be used to filter the returned AccessControls.

func WithAccessControlListOrder

func WithAccessControlListOrder(input ...types.AccessControlOrderByInput) func(options *AccessControlListOptions)

WithAccessControlListOrder can be used to specify the order of the returned AccessControl.

func WithAccessControlOverrideLocks

func WithAccessControlOverrideLocks() func(options *UpdateAccessControlOptions)

func WithAccessControlWhatAccessControlListFilter

func WithAccessControlWhatAccessControlListFilter(filter *types.AccessControlWhatAccessControlFilterInput) func(options *AccessControlWhatAccessControlListOptions)

WithAccessControlWhatAccessControlListFilter can be used to specify the filter of the returned AccessControlWhatAccessControlList.

func WithAccessControlWhatAccessControlListOrder

func WithAccessControlWhatAccessControlListOrder(input ...schema.AccessWhatOrderByInput) func(options *AccessControlWhatAccessControlListOptions)

WithAccessControlWhatAccessControlListOrder can be used to specify the order of the returned AccessControlWhatAccessControlList

func WithAccessControlWhatListFilter

func WithAccessControlWhatListFilter(input *types.AccessWhatFilterInput) func(options *AccessControlWhatListOptions)

WithAccessControlWhatListFilter can be used to filter the returned AccessControlWhatList.

func WithAccessControlWhatListOrder

func WithAccessControlWhatListOrder(input ...types.AccessWhatOrderByInput) func(options *AccessControlWhatListOptions)

WithAccessControlWhatListOrder can be used to specify the order of the returned AccessControlWhatList

func WithAccessControlWhoListOrder

func WithAccessControlWhoListOrder(input ...schema.AccessControlWhoOrderByInput) func(options *AccessControlWhoListOptions)

WithAccessControlWhoListOrder can be used to specify the order of the returned AccessControlWhoList

func WithDataObjectByExternalIdIncludeDataSource

func WithDataObjectByExternalIdIncludeDataSource() func(options *DataObjectByExternalIdOptions)

func WithDataObjectListFilter

func WithDataObjectListFilter(input *types.DataObjectFilterInput) func(options *DataObjectListOptions)

WithDataObjectListFilter sets the filter of the returned DataObjects in the ListDataObjects call

func WithDataObjectListOrder

func WithDataObjectListOrder(input ...types.DataObjectOrderByInput) func(options *DataObjectListOptions)

WithDataObjectListOrder sets the order of the returned DataObjects in the ListDataObjects call

func WithDataSourceListFilter

func WithDataSourceListFilter(input *types.DataSourceFilterInput) func(options *DataSourceListOptions)

WithDataSourceListFilter sets the filter of the returned DataSources in the ListDataSources call.

func WithDataSourceListOrder

func WithDataSourceListOrder(input ...types.DataSourceOrderByInput) func(options *DataSourceListOptions)

WithDataSourceListOrder sets the order of the returned DataSources in the ListDataSources call.

func WithDataSourceListSearch

func WithDataSourceListSearch(input *string) func(options *DataSourceListOptions)

WithDataSourceListSearch sets the search query of the returned DataSources in the ListDataSources call.

func WithExportOutOfSyncOnly

func WithExportOutOfSyncOnly() func(options *ExportOptions)

func WithJobListFilter

func WithJobListFilter(filter *types.JobsFilter) func(options *JobListOptions)

WithJobListFilter sets the filter for the job list.

func WithRoleAssignmentListFilter

func WithRoleAssignmentListFilter(input *types.RoleAssignmentFilterInput) func(options *RoleAssignmentListOptions)

WithRoleAssignmentListFilter sets the filter of the returned role assignments

func WithRoleAssignmentListOrder

func WithRoleAssignmentListOrder(input ...types.RoleAssignmentOrderInput) func(options *RoleAssignmentListOptions)

WithRoleAssignmentListOrder sets the order of the returned role assignments

Types

type AccessControlAbacWhatScopeListOptions

type AccessControlAbacWhatScopeListOptions struct {
	// contains filtered or unexported fields
}

type AccessControlClient

type AccessControlClient struct {
	// contains filtered or unexported fields
}

func NewAccessControlClient

func NewAccessControlClient(client graphql.Client) *AccessControlClient

func (*AccessControlClient) ActivateAccessControl

func (a *AccessControlClient) ActivateAccessControl(ctx context.Context, id string) (*types.AccessControl, error)

func (*AccessControlClient) CreateAccessControl

CreateAccessControl creates a new AccessControl. The valid AccessControl is returned if the creation is successful. Otherwise, an error is returned

func (*AccessControlClient) DeactivateAccessControl

func (a *AccessControlClient) DeactivateAccessControl(ctx context.Context, id string) (*types.AccessControl, error)

func (*AccessControlClient) DeleteAccessControl

func (a *AccessControlClient) DeleteAccessControl(ctx context.Context, id string, ops ...func(options *UpdateAccessControlOptions)) error

DeleteAccessControl deletes an existing AccessControl. If the deletion is successful, nil is returned. Otherwise, an error is returned.

func (*AccessControlClient) GetAccessControl

func (a *AccessControlClient) GetAccessControl(ctx context.Context, id string) (*types.AccessControl, error)

GetAccessControl returns a specific AccessControl

func (*AccessControlClient) GetAccessControlAbacWhatScope

func (a *AccessControlClient) GetAccessControlAbacWhatScope(ctx context.Context, id string, abacRule string, ops ...func(*AccessControlAbacWhatScopeListOptions)) iter.Seq2[*types.DataObject, error]

GetAccessControlAbacWhatScope returns all abac what scopes of an AccessControl id is the id of the AccessControl WithAccessControlAbacWhatScopeListSearch can be used to specify the search of the returned types.DataObject WithAccessControlAbacWhatScopeListOrder can be used to specify the order of the returned types.DataObject

func (*AccessControlClient) GetAccessControlWhatAccessControlList

func (a *AccessControlClient) GetAccessControlWhatAccessControlList(ctx context.Context, id string, ops ...func(*AccessControlWhatAccessControlListOptions)) iter.Seq2[*types.AccessWhatAccessControlItem, error]

GetAccessControlWhatAccessControlList returns all what access controls of an AccessControl.

func (*AccessControlClient) GetAccessControlWhatDataObjectList

func (a *AccessControlClient) GetAccessControlWhatDataObjectList(ctx context.Context, id string, ops ...func(*AccessControlWhatListOptions)) iter.Seq2[*types.AccessWhatDataObjectItem, error]

GetAccessControlWhatDataObjectList returns all what items of an AccessControl. The order of the list can be specified with WithAccessControlWhatListOrder. A channel is returned that can be used to receive the list of AccessWhatDataObjectItem. To close the channel ensure to cancel the context.

func (*AccessControlClient) GetAccessControlWhoList

func (a *AccessControlClient) GetAccessControlWhoList(ctx context.Context, id string, ops ...func(*AccessControlWhoListOptions)) iter.Seq2[*types.AccessWhoItem, error]

GetAccessControlWhoList returns all who items of an AccessControl. The order of the list can be specified with WithAccessControlWhoListOrder. A channel is returned that can be used to receive the list of AccessWhoItem. To close the channel ensure to cancel the context.

func (*AccessControlClient) ListAccessControls

func (a *AccessControlClient) ListAccessControls(ctx context.Context, ops ...func(*AccessControlListOptions)) iter.Seq2[*types.AccessControl, error]

ListAccessControls returns a list of AccessControls. The order of the list can be specified with WithAccessControlListOrder. A filter can be specified with WithAccessControlListFilter. A channel is returned that can be used to receive the list of AccessControls. To close the channel ensure to cancel the context.

func (*AccessControlClient) UpdateAccessControl

func (a *AccessControlClient) UpdateAccessControl(ctx context.Context, id string, ap schema.AccessControlInput, ops ...func(options *UpdateAccessControlOptions)) (*types.AccessControl, error)

UpdateAccessControl updates an existing AccessControl. The updated AccessControl is returned if the update is successful. Otherwise, an error is returned.

type AccessControlListOptions

type AccessControlListOptions struct {
	// contains filtered or unexported fields
}

type AccessControlWhatAccessControlListOptions

type AccessControlWhatAccessControlListOptions struct {
	// contains filtered or unexported fields
}

AccessControlWhatAccessControlListOptions options for listing what access controls of an AccessControl.

type AccessControlWhatListOptions

type AccessControlWhatListOptions struct {
	// contains filtered or unexported fields
}

type AccessControlWhoListOptions

type AccessControlWhoListOptions struct {
	// contains filtered or unexported fields
}

type DataObjectByExternalIdOptions

type DataObjectByExternalIdOptions struct {
	IncludeDataSource bool
}

type DataObjectClient

type DataObjectClient struct {
	// contains filtered or unexported fields
}

func NewDataObjectClient

func NewDataObjectClient(client graphql.Client) *DataObjectClient

func (*DataObjectClient) GetDataObject

func (c *DataObjectClient) GetDataObject(ctx context.Context, id string) (*types.DataObject, error)

GetDataObject returns a DataObject by id.

func (*DataObjectClient) GetDataObjectIdByName

func (c *DataObjectClient) GetDataObjectIdByName(ctx context.Context, fullName string, dataSource string, ops ...func(options *DataObjectByExternalIdOptions)) (string, error)

GetDataObjectIdByName returns the ID of the DataObject with the given name and dataSource.

func (*DataObjectClient) ListDataObjects

func (c *DataObjectClient) ListDataObjects(ctx context.Context, ops ...func(options *DataObjectListOptions)) iter.Seq2[*types.DataObject, error]

ListDataObjects returns a list of DataObjects The order of the list can be specified with WithDataObjectListOrder A filter can be specified with WithDataObjectListFilter A channel is returned that can be used to receive the list of DataObjectListItem To close the channel ensure to cancel the context

type DataObjectListOptions

type DataObjectListOptions struct {
	// contains filtered or unexported fields
}

type DataSourceClient

type DataSourceClient struct {
	// contains filtered or unexported fields
}

func NewDataSourceClient

func NewDataSourceClient(client graphql.Client) *DataSourceClient

func (*DataSourceClient) CreateDataSource

func (c *DataSourceClient) CreateDataSource(ctx context.Context, ds types.DataSourceInput) (*types.DataSource, error)

CreateDataSource creates a new DataSource. Returns the newly created DataSource if successful. Otherwise, returns an error.

func (*DataSourceClient) DeleteDataSource

func (c *DataSourceClient) DeleteDataSource(ctx context.Context, id string) error

DeleteDataSource deletes an existing DataSource. Returns nil if successful. Otherwise, returns an error.

func (*DataSourceClient) GetDataSource

func (c *DataSourceClient) GetDataSource(ctx context.Context, id string) (*types.DataSource, error)

GetDataSource returns an existing DataSource.

func (*DataSourceClient) GetMaskingMetadata

func (c *DataSourceClient) GetMaskingMetadata(ctx context.Context, id string) (*types.MaskingMetadata, error)

GetMaskingMetadata Get masking information for a DataSource

func (*DataSourceClient) ListDataSources

func (c *DataSourceClient) ListDataSources(ctx context.Context, ops ...func(*DataSourceListOptions)) iter.Seq2[*types.DataSource, error]

ListDataSources return a list of DataSources The order of the list can be specified with WithDataSourceListOrder. A filter can be specified with WithDataSourceListFilter. A channel is returned that can be used to receive the list of DataSourceListItem. To close the channel ensure to cancel the context.

func (*DataSourceClient) SetDataSourceMetadata

func (c *DataSourceClient) SetDataSourceMetadata(ctx context.Context, id string, metadata types.DataSourceMetaDataInput) (*types.DataSource, error)

func (*DataSourceClient) SetSyncConfigurationParameterValues added in v0.0.56

func (c *DataSourceClient) SetSyncConfigurationParameterValues(ctx context.Context, input types.SyncParameterValuesInput) (*types.DataSource, error)

SetSyncConfigurationParameterValues sets sync configuration parameter values for a DataSource. Each value's Path identifies the configuration key. Value can be any JSON-serializable type (bool, number, string, map, …); a nil value removes the parameter. Returns the updated DataSource if successful, otherwise returns an error.

func (*DataSourceClient) TriggerDataSourceCliSync added in v0.0.57

func (c *DataSourceClient) TriggerDataSourceCliSync(ctx context.Context, request types.DataSourceSyncRequest) (*types.DataSource, error)

TriggerDataSourceCliSync manually triggers a CLI synchronization for a DataSource. Returns the updated DataSource if successful, otherwise returns an error.

func (*DataSourceClient) UpdateDataSource

func (c *DataSourceClient) UpdateDataSource(ctx context.Context, id string, ds types.DataSourceInput) (*types.DataSource, error)

UpdateDataSource updates an existing DataSource. Returns the updated DataSource if successful. Otherwise, returns an error.

type DataSourceListOptions

type DataSourceListOptions struct {
	// contains filtered or unexported fields
}

DataSourceListOptions list options for listing DataSources.

type ExportOptions

type ExportOptions struct {
	OnlyOutOfSync bool
}

type ExporterClient

type ExporterClient struct {
	// contains filtered or unexported fields
}

func NewExporterClient

func NewExporterClient(client graphql.Client) *ExporterClient

func (*ExporterClient) FetchExportAccessControls

func (c *ExporterClient) FetchExportAccessControls(ctx context.Context, flowId uuid.UUID, ops ...FetchExportAccessControlsOption) iter.Seq2[types.ExportedItem, error]

FetchExportAccessControls streams the access controls exported in the given flow.

func (*ExporterClient) FinishExportFlow

func (c *ExporterClient) FinishExportFlow(ctx context.Context, flowId uuid.UUID, startTime time.Time) (bool, error)

FinishExportFlow finishes an export flow.

func (*ExporterClient) StartExportFlow

func (c *ExporterClient) StartExportFlow(ctx context.Context, flowId uuid.UUID, ops ...func(*ExportOptions)) (*types.StartExportFlow, error)

StartExportFlow starts a new export flow.

type FetchExportAccessControlsOption added in v0.0.31

type FetchExportAccessControlsOption func(params *FetchExportAccessControlsParams)

func WithFetchExportAccessControlsLastSequenceId added in v0.0.31

func WithFetchExportAccessControlsLastSequenceId(lastSequenceId int) FetchExportAccessControlsOption

func WithFetchExportAccessControlsStartSequenceId added in v0.0.32

func WithFetchExportAccessControlsStartSequenceId(startSequenceId int) FetchExportAccessControlsOption

type FetchExportAccessControlsParams added in v0.0.31

type FetchExportAccessControlsParams struct {
	StartSequenceId int
	LastSequenceId  *int
}

type GrantCategoryClient

type GrantCategoryClient struct {
	// contains filtered or unexported fields
}

func NewGrantCategoryClient

func NewGrantCategoryClient(client graphql.Client) *GrantCategoryClient

func (*GrantCategoryClient) CreateGrantCategory

func (a *GrantCategoryClient) CreateGrantCategory(ctx context.Context, category types.GrantCategoryInput) (*types.GrantCategoryDetails, error)

CreateGrantCategory creates a new GrantCategory. The newly created GrantCategory is returned if successful. Otherwise, an error is returned.

func (*GrantCategoryClient) DeleteGrantCategory

func (a *GrantCategoryClient) DeleteGrantCategory(ctx context.Context, id string) error

DeleteGrantCategory deletes an existing GrantCategory. Returns nil if successful. Otherwise, returns an error.

func (*GrantCategoryClient) GetGrantCategory

func (a *GrantCategoryClient) GetGrantCategory(ctx context.Context, id string) (*types.GrantCategoryDetails, error)

GetGrantCategory retrieves an existing GrantCategory. Returns the GrantCategory if successful. Otherwise, returns an error.

func (*GrantCategoryClient) ListGrantCategories

func (a *GrantCategoryClient) ListGrantCategories(ctx context.Context) ([]types.GrantCategoryDetails, error)

ListGrantCategories retrieves all GrantCategories Returns a list of GrantCategories if successful. Otherwise, returns an error.

func (*GrantCategoryClient) UpdateGrantCategory

func (a *GrantCategoryClient) UpdateGrantCategory(ctx context.Context, id string, category types.GrantCategoryInput) (*types.GrantCategoryDetails, error)

UpdateGrantCategory updates an existing GrantCategory. The updated GrantCategory is returned if successful. Otherwise, an error is returned.

type ImporterClient

type ImporterClient struct {
	// contains filtered or unexported fields
}

func NewImporterClient

func NewImporterClient(client graphql.Client) *ImporterClient

func (*ImporterClient) FinishImportFlow

func (c *ImporterClient) FinishImportFlow(ctx context.Context, flowId uuid.UUID, options ...ImporterFinishImportFlowOption) error

FinishImportFlow finishes an import flow.

func (*ImporterClient) ImportHeartbeat added in v0.0.28

func (c *ImporterClient) ImportHeartbeat(ctx context.Context, flowId uuid.UUID) (*types.Subtask, error)

func (*ImporterClient) StartImportFlow

func (c *ImporterClient) StartImportFlow(ctx context.Context, input types.StartImportFlowInput) (*types.Subtask, error)

StartImportFlow starts a new import flow.

func (*ImporterClient) SubmitImportObjects

func (c *ImporterClient) SubmitImportObjects(ctx context.Context, input types.ImportCommands) (*types.SubmittedCommands, error)

SubmitImportObjects submits objects to an import flow.

func (*ImporterClient) SupportedCliVersion

func (c *ImporterClient) SupportedCliVersion(ctx context.Context) (*types.SupportedCliVersion, error)

type ImporterFinishImportFlowOption added in v0.0.29

type ImporterFinishImportFlowOption func(input *types.FinishImportFlowOptionsInput)

func WithImporterFinishImportFlowSkipCleanup added in v0.0.29

func WithImporterFinishImportFlowSkipCleanup(skip bool) ImporterFinishImportFlowOption

type JobClient

type JobClient struct {
	// contains filtered or unexported fields
}

func NewJobClient

func NewJobClient(client graphql.Client) *JobClient

func (*JobClient) AddSubtaskEvent

func (c *JobClient) AddSubtaskEvent(ctx context.Context, input types.SubtaskInput) (*types.Subtask, error)

AddSubtaskEvent adds a subtask event.

func (*JobClient) AddTaskEvent

func (c *JobClient) AddTaskEvent(ctx context.Context, input types.TaskEventInput) (*types.Task, error)

AddTaskEvent adds a task event.

func (*JobClient) CreateJob

func (c *JobClient) CreateJob(ctx context.Context, input types.JobInput) (*types.Job, error)

CreateJob creates a new job.

func (*JobClient) EndOfTargetsSync

func (c *JobClient) EndOfTargetsSync(ctx context.Context, input types.EndOfTargetsSyncInput) error

EndOfTargetsSync signals the end of targets sync.

func (*JobClient) GetJob

func (c *JobClient) GetJob(ctx context.Context, id string) (*types.Job, error)

GetJob returns a job by its ID.

func (*JobClient) GetSubtaskOfTask

func (c *JobClient) GetSubtaskOfTask(ctx context.Context, jobId, taskType, subtaskId string) (*types.Subtask, error)

GetSubtaskOfTask returns a subtask by its job ID, task type and subtask ID.

func (*JobClient) GetTask

func (c *JobClient) GetTask(ctx context.Context, jobId string, taskType string) (*types.Task, error)

GetTask returns a task by its job ID and task type.

func (*JobClient) ListJobs

func (c *JobClient) ListJobs(ctx context.Context, ops ...func(*JobListOptions)) iter.Seq2[*types.Job, error]

ListJobs returns a channel that will receive the list of jobs.

func (*JobClient) ListTasksOfJob

func (c *JobClient) ListTasksOfJob(ctx context.Context, jobId string) iter.Seq2[*types.Task, error]

ListTasksOfJob returns a channel that will receive the list of tasks for a job.

func (*JobClient) UpdateJob

func (c *JobClient) UpdateJob(ctx context.Context, id string, input types.JobInput) (*types.Job, error)

UpdateJob updates an existing job.

type JobListOptions

type JobListOptions struct {
	// contains filtered or unexported fields
}

type RoleAssignmentListOptions

type RoleAssignmentListOptions struct {
	// contains filtered or unexported fields
}

type RoleClient

type RoleClient struct {
	// contains filtered or unexported fields
}

func NewRoleClient

func NewRoleClient(client graphql.Client) *RoleClient

func (*RoleClient) GetRole

func (c *RoleClient) GetRole(ctx context.Context, id string) (*types.Role, error)

GetRole returns a role by ID Returns a Role if role is retrieved successfully, otherwise returns an error.

func (*RoleClient) ListRoleAssignments

func (c *RoleClient) ListRoleAssignments(ctx context.Context, ops ...func(*RoleAssignmentListOptions)) iter.Seq2[*types.RoleAssignment, error]

ListRoleAssignments returns a list of role assignments for a given role The order of the list can be specified with WithRoleAssignmentListOrder. A filter can be specified with WithRoleAssignmentListFilter A channel is returned that can be used to receive the list of types.RoleAssignment To close the channel ensure to cancel the context.

func (*RoleClient) ListRoleAssignmentsOnAccessControl

func (c *RoleClient) ListRoleAssignmentsOnAccessControl(ctx context.Context, accessControlId string, ops ...func(*RoleAssignmentListOptions)) iter.Seq2[*types.RoleAssignment, error]

ListRoleAssignmentsOnAccessControl returns a list of role assignments for a given role on an access control. The order of the list can be specified with WithRoleAssignmentListOrder. A filter can be specified with WithRoleAssignmentListFilter. A channel is returned that can be used to receive the list of types.RoleAssignment. To close the channel ensure to cancel the context.

func (*RoleClient) ListRoleAssignmentsOnDataObject

func (c *RoleClient) ListRoleAssignmentsOnDataObject(ctx context.Context, objectId string, ops ...func(*RoleAssignmentListOptions)) iter.Seq2[*types.RoleAssignment, error]

ListRoleAssignmentsOnDataObject returns a list of role assignments for a given role on a given data object The order of the list can be specified with WithRoleAssignmentListOrder. A filter can be specified with WithRoleAssignmentListFilter. A channel is returned that can be used to receive the list of types.RoleAssignment. To close the channel ensure to cancel the context.

func (*RoleClient) ListRoleAssignmentsOnDataSource

func (c *RoleClient) ListRoleAssignmentsOnDataSource(ctx context.Context, dataSourceId string, ops ...func(*RoleAssignmentListOptions)) iter.Seq2[*types.RoleAssignment, error]

ListRoleAssignmentsOnDataSource returns a list of role assignments for a given role on a given data source The order of the list can be specified with WithRoleAssignmentListOrder. A filter can be specified with WithRoleAssignmentListFilter. A channel is returned that can be used to receive the list of types.RoleAssignment. To close the channel ensure to cancel the context.

func (*RoleClient) ListRoleAssignmentsOnUser

func (c *RoleClient) ListRoleAssignmentsOnUser(ctx context.Context, userId string, ops ...func(*RoleAssignmentListOptions)) iter.Seq2[*types.RoleAssignment, error]

ListRoleAssignmentsOnUser returns a list of role assignments for a given role on a given user. The order of the list can be specified with WithRoleAssignmentListOrder. A filter can be specified with WithRoleAssignmentListFilter. A channel is returned that can be used to receive the list of types.RoleAssignment. To close the channel ensure to cancel the context.

func (*RoleClient) UpdateRoleAssigneesOnAccessControl

func (c *RoleClient) UpdateRoleAssigneesOnAccessControl(ctx context.Context, accessControlId string, roleId string, assignees ...string) (*types.Role, error)

UpdateRoleAssigneesOnAccessControl updates a role assignment between an access control and a set of users. Existing role assignments will be overwritten. accessControlId is the id of the access provider to assign the role to. roleId is the id of the role to assign. assignees is a list of user ids to assign the role to.

func (*RoleClient) UpdateRoleAssigneesOnDataObject

func (c *RoleClient) UpdateRoleAssigneesOnDataObject(ctx context.Context, doId string, roleId string, assignees ...string) (*types.Role, error)

UpdateRoleAssigneesOnDataObject updates a role assignment between a data object and a set of users. Existing role assignments will be overwritten. doId is the id of the data object to assign the role to. roleId is the id of the role to assign. assignees is a list of user ids to assign the role to.

func (*RoleClient) UpdateRoleAssigneesOnDataSource

func (c *RoleClient) UpdateRoleAssigneesOnDataSource(ctx context.Context, dataSourceId string, roleId string, assignees ...string) (*types.Role, error)

UpdateRoleAssigneesOnDataSource updates a role assignment between a data source and a set of users Existing role assignments will be overwritten. dataSourceId is the id of the data source to assign the role to. roleId is the id of the role to assign. assignees is a list of user ids to assign the role to.

type SiteService added in v0.0.27

type SiteService struct {
	// contains filtered or unexported fields
}

func NewSiteService added in v0.0.27

func NewSiteService(client graphql.Client) *SiteService

func (*SiteService) NextSyncJobForEdgeDataSource added in v0.0.49

func (s *SiteService) NextSyncJobForEdgeDataSource(ctx context.Context, syncInput types.SyncJobForEdgeDataSourceInput) (*types.SyncJob, error)

func (*SiteService) SiteInfo added in v0.0.39

func (s *SiteService) SiteInfo(ctx context.Context, siteId string) (*types.EdgeSiteInfoResult, error)

func (*SiteService) UpdateSiteSettings added in v0.0.27

func (s *SiteService) UpdateSiteSettings(ctx context.Context, siteInfo types.EdgeSiteInfoInput) error

type UpdateAccessControlOptions

type UpdateAccessControlOptions struct {
	// contains filtered or unexported fields
}

type UserClient

type UserClient struct {
	// contains filtered or unexported fields
}

func NewUserClient

func NewUserClient(client graphql.Client) *UserClient

func (*UserClient) CreateUser

func (c *UserClient) CreateUser(ctx context.Context, userInput types.UserInput) (*types.User, error)

CreateUser creates a new user in Collibra Data Access Returns a User if user is created successfully, otherwise returns an error.

func (*UserClient) GetCurrentUser

func (c *UserClient) GetCurrentUser(ctx context.Context) (*types.User, error)

func (*UserClient) GetUser

func (c *UserClient) GetUser(ctx context.Context, id string) (*types.User, error)

GetUser returns the user with the given ID. Returns a User if the user is found, otherwise returns an error.

func (*UserClient) GetUserByEmail

func (c *UserClient) GetUserByEmail(ctx context.Context, email string) (*types.User, error)

GetUserByEmail Get a user by their email address. Returns a User if user is found, otherwise returns an error.

func (*UserClient) UpdateUser

func (c *UserClient) UpdateUser(ctx context.Context, id string, userInput types.UserInput) (*types.User, error)

UpdateUser updates an existing user in Collibra Data Access Returns a User if user is updated successfully, otherwise returns an error.

Jump to